/*** Animated Footsteps ***
 * 
 * This Arduino file is part of:
 * ROUTES, a project by Maria Gabriella Astolfo, Alberto Elizondo and Marco Righetto
 * http://www.interaction-venice.com/projects/iuav09-10Lab2/about/routes/
 * 
 * IUAV University of Venice - Design&Arts Faculty
 * IxD Lab 2 - January-April 2010
 * 
 * Tutors: Philip Tabor and Gillian Crampton-Smith
 * Thanks to Tom Hulbert and Durrel Bishop
 * 
 ***/


int wait = 1000;
int action;  // serial input variable

/*** SERVOS ***/
#include <Servo.h>  // use library for servo controlling

Servo myservoLeft;  // create servo objects to control a servo 
Servo myservoRight;

int servoLeftPin = 9;  // declare pins for servos (pwm)
int servoRightPin = 10;

int pos[] = { 
  71, 84, 92, 109 };  // positions for footsteps projections (degrees)

int centerServo;      // variable to give servo a center position

/*** LEDS ***/
int leftLedPin = 5;   // PWM pin for Left LED
int rightLedPin = 6;  // PWM pin for Right LED

boolean stateLeft;  // set variables for LEDs state
boolean stateRight;



void setup() {

  // servos setup
  myservoLeft.attach(servoLeftPin);  // attach the servos to the servo objects
  myservoRight.attach(servoRightPin); 

  centerServo = 90;  // standby position for projector (centered, perpendicular to the floor)

  // leds setup
  pinMode(leftLedPin, OUTPUT);  // set led pins as outputs
  pinMode(rightLedPin, OUTPUT);

  stateRight = LOW;  // set LEDs initial states
  stateLeft = HIGH;

  // serial communication setup 
  Serial.begin(9600);  //serial port
  Serial.println("Arduino Serial Servo Control");  // text that will appear in the serial monitor as instruction
  Serial.println("Press spacebar to start animation");
  Serial.println();

}


void loop() {
  if (Serial.available() > 0) {  // checks if serial port is ready

    action = Serial.read();  // reads serial inputs

    if (action == 32) {      // 32 is 'spacebar' in the ASCII chart 
      // this activates the animation

      myservoRight.write(pos[3]); // servos move in the footstep position
      myservoLeft.write(pos[0]); 
      ledOnOff();  // this calls a function to control leds light
      delay(wait); // delay between a footstep and the following

      myservoLeft.write(pos[2]); 
      ledOnOff();
      delay(wait);

      myservoRight.write(pos[1]);
      ledOnOff();
      delay(wait);

      myservoLeft.write(pos[3]); 
      ledOnOff();
      delay(wait);

      myservoLeft.write(centerServo); 
      myservoRight.write(centerServo); 
      analogWrite(leftLedPin, 0);  // set the leds off waiting for the next "call"
      analogWrite(rightLedPin, 0);     
      delay(wait);

    }
  }
}


void ledOnOff() {  // this function sets the leds on and off alternatively with fading

  if (stateLeft == LOW && stateRight == HIGH) {
    stateLeft = HIGH;
    stateRight = LOW;
    for(int fadeValue = 0 ; fadeValue <= 255; fadeValue +=3) { 
      analogWrite(leftLedPin, fadeValue);  
      delay(20);
      analogWrite(rightLedPin, 255-fadeValue);       
      delay(5);                            
    } 
    digitalWrite(leftLedPin, stateLeft);   
    digitalWrite(rightLedPin, stateRight);  
  }

  else if (stateLeft == HIGH && stateRight == LOW) {
    stateLeft = LOW;
    stateRight = HIGH;
    for(int fadeValue = 255 ; fadeValue >= 0; fadeValue -=3) { 
      analogWrite(leftLedPin, fadeValue);  
      delay(5); 
      analogWrite(rightLedPin, 255-fadeValue);        
      delay(20);                            
    } 
    digitalWrite(leftLedPin, stateLeft);  
    digitalWrite(rightLedPin, stateRight);   
  }

}


